checkVariablesNames checks reporting and mappings on inconsistency in variable names
Source:R/checkVarNames.R
checkVarNames.RdPass a vector of variable names (including the units if withunits=TRUE) or a quitte object. Get warnings if inconsistencies are found for the reporting