Skip to content

add missing variable values if the value can be obtained from two other reported results.

Usage

fillSummationPairs(mifFile, summationsFile)

Arguments

mifFile

path to mif file or a quitte object

summationsFile

in inst/summations folder that describes the required summation groups, or path to summations file

Author

Renato Rodrigues