Skip to content

Add price index

Usage

priceIndicesAdd(mifdata, priceIndices, scenBase = NULL, referenceYear = 2020)

Arguments

mifdata

file or data that can be converted into quitte object

priceIndices

vector of missing price index variable names

scenBase

optional scenario name of baseline scenario used to calculate index

referenceYear

in which index = 1

Author

Oliver Richters