Check NGFS submission by comparing mif data to a template file (xlsx or yaml) provided by IIASA
Source:R/checkNGFS.R
checkNGFS.RdCheck NGFS submission by comparing mif data to a template file (xlsx or yaml) provided by IIASA
R/checkNGFS.R
checkNGFS.RdCheck NGFS submission by comparing mif data to a template file (xlsx or yaml) provided by IIASA