This function checks whether the piam_factor in a mapping fits unit and piam_unit. It does the following:
check whether the units are identical based on areUnitsIdentical() and piam_factor is 1 or -1.
based on scaleConversion defined below, check whether manually added factors are satisfied This works based on regex matching, so for example 1000 TW = 1 PW is matched by the c("1000", "T", "P") line. If the tests fail because of a new unit, you can add them below. If the units are really identical except for spelling, better add them to areUnitsIdentical.R