Recursively calculate additional variables based on given summations and add them to the given mif file
Source:R/fillMissingSummations.R
fillMissingSummations.RdRecursively calculate additional variables based on given summations and add them to the given mif file