R/priceIndicesAdd.R
priceIndicesAdd.Rd
Add price index
priceIndicesAdd(mifdata, priceIndices, scenBase = NULL, referenceYear = 2020)
file or data that can be converted into quitte object
vector of missing price index variable names
optional scenario name of baseline scenario used to calculate index
in which index = 1
Oliver Richters