Loads data and replaces all variables with the |+| notation used in this data. Pick a mif file or quitte object and run: Rscript -e 'devtools::load_all(); updatePlusUnit("your.mif")'
Loads data and replaces all variables with the |+| notation used in this data. Pick a mif file or quitte object and run: Rscript -e 'devtools::load_all(); updatePlusUnit("your.mif")'